@@ -14,7 +14,9 @@
 
 """Exceptions for the Brick library."""
 
+from oslo_concurrency import processutils as putils
 import six
+import traceback
 
 from os_brick.i18n import _
 from oslo_log import log as logging
@@ -151,6 +153,11 @@ class InvalidIOHandleObject(BrickException):
                 'type %(actual_type)s.')
 
 
+class VolumeDeviceValidationFailed(BrickException):
+    message = _("Volume device validation failed for device %(device)s "
+                "(expected %(expected)s, found %(found)s.")
+
+
 class VolumeEncryptionNotSupported(Invalid):
     message = _("Volume encryption is not supported for %(volume_type)s "
                 "volume %(volume_id)s.")
@@ -161,9 +168,68 @@ class InvalidConnectorProtocol(ValueError):
     pass
 
 
-class HostChannelsTargetsNotFound(BrickException):
-    message = _('Unable to find host, channel, and target for %(iqns)s.')
+class ExceptionChainer(BrickException):
+    """A Exception that can contain a group of exceptions.
 
-    def __init__(self, message=None, iqns=None, found=None):
-        super(HostChannelsTargetsNotFound, self).__init__(message, iqns=iqns)
-        self.found = found
+    This exception serves as a container for exceptions, useful when we want to
+    store all exceptions that happened during a series of steps and then raise
+    them all together as one.
+
+    The representation of the exception will include all exceptions and their
+    tracebacks.
+
+    This class also includes a context manager for convenience, one that will
+    support both swallowing the exception as if nothing had happened and
+    raising the exception.  In both cases the exception will be stored.
+
+    If a message is provided to the context manager it will be formatted and
+    logged with warning level.
+    """
+    def __init__(self, *args, **kwargs):
+        self._exceptions = []
+        self._repr = None
+        super(ExceptionChainer, self).__init__(*args, **kwargs)
+
+    def __repr__(self):
+        # Since generating the representation can be slow we cache it
+        if not self._repr:
+            tracebacks = (
+                ''.join(traceback.format_exception(*e)).replace('\n', '\n\t')
+                for e in self._exceptions)
+            self._repr = '\n'.join('\nChained Exception #%s\n\t%s' % (i + 1, t)
+                                   for i, t in enumerate(tracebacks))
+        return self._repr
+
+    __str__ = __unicode__ = __repr__
+
+    def __nonzero__(self):
+        # We want to be able to do boolean checks on the exception
+        return bool(self._exceptions)
+
+    __bool__ = __nonzero__  # For Python 3
+
+    def add_exception(self, exc_type, exc_val, exc_tb):
+        # Clear the representation cache
+        self._repr = None
+        self._exceptions.append((exc_type, exc_val, exc_tb))
+
+    def context(self, catch_exception, msg='', *msg_args):
+        self._catch_exception = catch_exception
+        self._exc_msg = msg
+        self._exc_msg_args = msg_args
+        return self
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        if exc_type:
+            self.add_exception(exc_type, exc_val, exc_tb)
+            if self._exc_msg:
+                LOG.warning(self._exc_msg, *self._exc_msg_args)
+            if self._catch_exception:
+                return True
+
+
+class ExecutionTimeout(putils.ProcessExecutionError):
+    pass
