@@ -195,6 +195,7 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         except exception.TargetPortalsNotFound:
             raise
         except Exception:
+            LOG.exception('Exception encountered during portal discovery')
             if 'target_portals' in connection_properties:
                 raise exception.TargetPortalsNotFound(
                     target_portals=connection_properties['target_portals'])
@@ -538,6 +539,9 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         return symlink
 
     def _get_connect_result(self, con_props, wwn, devices_names, mpath=None):
+        if 'wwn' in con_props:
+            self._linuxscsi.verify_sysfs_wwns(devices_names, con_props['wwn'])
+
         device = '/dev/' + (mpath or devices_names[0])
 
         # NOTE(geguileo): This is only necessary because of the current
@@ -707,6 +711,13 @@ class ISCSIConnector(base.BaseLinuxConnector, base_iscsi.BaseISCSIConnector):
         for ip, iqn, lun in ips_iqns_luns:
             props = connection_properties.copy()
             props.update(target_portal=ip, target_iqn=iqn, target_lun=lun)
+
+            # NOTE(yenai): The method _connect_vol is used for parallelize
+            # logins, we shouldn't give these arguments; and it will make a
+            # mess in the debug message in _connect_vol. So, kick them out:
+            for key in ('target_portals', 'target_iqns', 'target_luns'):
+                props.pop(key, None)
+
             threads.append(executor.Thread(target=self._connect_vol,
                                            args=(retries, props, data)))
         for thread in threads:
