@@ -32,8 +32,8 @@ from os_brick import utils
 
 LOG = logging.getLogger(__name__)
 
-MULTIPATH_ERROR_REGEX = re.compile("\w{3} \d+ \d\d:\d\d:\d\d \|.*$")
-MULTIPATH_WWID_REGEX = re.compile("\((?P<wwid>.+)\)")
+MULTIPATH_ERROR_REGEX = re.compile(r"\w{3} \d+ \d\d:\d\d:\d\d \|.*$")
+MULTIPATH_WWID_REGEX = re.compile(r"\((?P<wwid>.+)\)")
 MULTIPATH_DEVICE_ACTIONS = ['unchanged:', 'reject:', 'reload:',
                             'switchpg:', 'rename:', 'create:',
                             'resize:']
@@ -154,6 +154,16 @@ class LinuxSCSI(executor.Executor):
             return udev_wwid
         return ''
 
+    def verify_sysfs_wwns(self, device_names, expected_wwn):
+        """Verify that all specified devices have the expected WWN."""
+
+        for device_name in device_names:
+            found_wwn = self.get_sysfs_wwn([device_name])
+            if found_wwn != expected_wwn:
+                raise exception.VolumeDeviceValidationFailed(
+                    device=device_name, expected=expected_wwn,
+                    found=found_wwn)
+
     def get_scsi_wwn(self, path):
         """Read the WWN from page 0x83 value for a SCSI device."""
 
@@ -445,8 +455,8 @@ class LinuxSCSI(executor.Executor):
             lines = out.strip()
             lines = lines.split("\n")
             lines = [line for line in lines
-                     if not re.match(MULTIPATH_ERROR_REGEX, line)
-                     and len(line)]
+                     if not re.match(MULTIPATH_ERROR_REGEX, line) and
+                     len(line)]
             if lines:
 
                 mdev_name = lines[0].split(" ")[0]
