@@ -17,6 +17,7 @@ import sys
 
 import mock
 from oslo_concurrency import processutils as putils
+from oslo_service import loopingcall
 
 from os_brick import exception
 from os_brick.initiator import connector
@@ -32,6 +33,12 @@ MY_IP = '10.0.0.1'
 FAKE_SCSI_WWN = '1234567890'
 
 
+class ZeroIntervalLoopingCall(loopingcall.FixedIntervalLoopingCall):
+    def start(self, interval, initial_delay=None, stop_on_exception=True):
+        return super(ZeroIntervalLoopingCall, self).start(
+            0, 0, stop_on_exception)
+
+
 class ConnectorUtilsTestCase(test_base.TestCase):
 
     @mock.patch.object(nvme.NVMeConnector, '_get_system_uuid',
@@ -126,6 +133,8 @@ class ConnectorTestCase(test_base.TestCase):
     def setUp(self):
         super(ConnectorTestCase, self).setUp()
         self.cmds = []
+        self.mock_object(loopingcall, 'FixedIntervalLoopingCall',
+                         ZeroIntervalLoopingCall)
 
     def fake_execute(self, *cmd, **kwargs):
         self.cmds.append(" ".join(cmd))
@@ -244,10 +253,6 @@ class ConnectorTestCase(test_base.TestCase):
             'huaweisdshypervisor', None, arch='x86_64')
         self.assertEqual("HuaweiStorHyperConnector", obj.__class__.__name__)
 
-        obj = connector.InitiatorConnector.factory(
-            "scaleio", None, arch='x86_64')
-        self.assertEqual("ScaleIOConnector", obj.__class__.__name__)
-
         obj = connector.InitiatorConnector.factory(
             'quobyte', None, quobyte_mount_point_base='/mnt/test',
             arch='x86_64')
@@ -257,6 +262,15 @@ class ConnectorTestCase(test_base.TestCase):
             "disco", None, arch='x86_64')
         self.assertEqual("DISCOConnector", obj.__class__.__name__)
 
+        obj = connector.InitiatorConnector.factory(
+            "vxflexos", None, arch='x86_64')
+        self.assertEqual("VxFlexOsConnector", obj.__class__.__name__)
+
+        # check deprecated protocol mapping
+        obj = connector.InitiatorConnector.factory(
+            "scaleio", None, arch='x86_64')
+        self.assertEqual("VxFlexOsConnector", obj.__class__.__name__)
+
         self.assertRaises(exception.InvalidConnectorProtocol,
                           connector.InitiatorConnector.factory,
                           "bogus", None)
